@@ -3,13 +3,13 @@ const regenerate = require('regenerate');
 
 test('regenerate-unicode-properties', t => {
 	t.true(
-		require('../Binary_Property/ASCII.js') instanceof regenerate
+		require('../Binary_Property/ASCII.js').characters instanceof regenerate
 	);
 	t.true(
-		require('../Binary_Property/Emoji.js') instanceof regenerate
+		require('../Binary_Property/Emoji.js').characters instanceof regenerate
 	);
 	t.true(
-		require('../Binary_Property/Emoji.js').toRegExp().test('\u{1F921}') // U+1F921 CLOWN FACE
+		require('../Binary_Property/Emoji.js').characters.toRegExp().test('\u{1F921}') // U+1F921 CLOWN FACE
 	);
 	t.throws(
 		() => require('../Invalid_Property/X.js'),
